@@ -80,17 +80,20 @@ refpkg(refpkg_path,type="krona")
 d <- cophenetic.phylo(root_tree)
 
 ids <- NULL
-for(usp in unique(info$species)){
+for(i in 1:length(unique(info$species))){
+    usp <- unique(info$species)[i]
   sub <- info[as.character(info$species)==usp,]
-  if(nrow(sub)<=10){
-    ids <- c(ids,as.character(sub[,1]))
+  acc <- as.character(sub[,1])
+  
+  # the following code line prevent the code from crashing
+  # i.e. new sequences not available in the example may be uploaded
+  # when you will run the code
+  acc <- acc[!is.na(match(acc,colnames(d)))]
+
+  if(length(acc)<=10){
+    ids <- c(ids,acc)
   }
-  if(nrow(sub)>10){
-    acc <- as.character(sub[,1])
-    # the following code line prevent the code from crashing
-    # i.e. new sequences not available in the example may be uploaded
-	# when you will run the code
-    acc <- acc[!is.na(match(acc,colnames(d)))]
+  if(length(acc)>10){
     h <- hclust(as.dist(d[acc,acc]))
     grp <- cutree(h,k=10)
     ids <- c(ids,names(grp)[match(1:10,grp)])
